@@ -1,3 +1,4 @@
+import math
 import unittest
 
 from leeger.calculator.all_time_calculator.ScoringStandardDeviationAllTimeCalculator import \
@@ -55,6 +56,44 @@ class TestScoringStandardDeviationAllTimeCalculator(unittest.TestCase):
         self.assertEqual(Deci("0.08164965809277260327324280249"), response[owners[4].id])
         self.assertEqual(Deci("0.08164965809277260327324280249"), response[owners[5].id])
 
+    def test_getScoringStandardDeviation_multiWeekMatchups(self):
+        owners, teamsA = getNDefaultOwnersAndTeams(6)
+        teamsB = getTeamsFromOwners(owners)
+        teamsC = getTeamsFromOwners(owners)
+
+        matchup1_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=1.1, teamBScore=2.1,
+                             multiWeekMatchupId="1")
+        matchup2_a = Matchup(teamAId=teamsA[2].id, teamBId=teamsA[3].id, teamAScore=3.1, teamBScore=4.1)
+        matchup3_a = Matchup(teamAId=teamsA[4].id, teamBId=teamsA[5].id, teamAScore=4.1, teamBScore=5.1)
+        week1_a = Week(weekNumber=1, matchups=[matchup1_a, matchup2_a, matchup3_a])
+        yearA = Year(yearNumber=2000, teams=teamsA, weeks=[week1_a])
+
+        matchup1_b = Matchup(teamAId=teamsB[0].id, teamBId=teamsB[1].id, teamAScore=1.2, teamBScore=2.2,
+                             multiWeekMatchupId="1")
+        matchup2_b = Matchup(teamAId=teamsB[2].id, teamBId=teamsB[3].id, teamAScore=3.2, teamBScore=4.2)
+        matchup3_b = Matchup(teamAId=teamsB[4].id, teamBId=teamsB[5].id, teamAScore=4.2, teamBScore=5.2)
+        week1_b = Week(weekNumber=1, matchups=[matchup1_b, matchup2_b, matchup3_b])
+        yearB = Year(yearNumber=2001, teams=teamsB, weeks=[week1_b])
+
+        matchup1_c = Matchup(teamAId=teamsC[0].id, teamBId=teamsC[1].id, teamAScore=1.3, teamBScore=2.3)
+        matchup2_c = Matchup(teamAId=teamsC[2].id, teamBId=teamsC[3].id, teamAScore=3.3, teamBScore=4.3)
+        matchup3_c = Matchup(teamAId=teamsC[4].id, teamBId=teamsC[5].id, teamAScore=4.3, teamBScore=5.3)
+        week1_c = Week(weekNumber=1, matchups=[matchup1_c, matchup2_c, matchup3_c])
+        yearC = Year(yearNumber=2002, teams=teamsC, weeks=[week1_c])
+
+        league = League(name="TEST", owners=owners, years=[yearA, yearB, yearC])
+
+        response = ScoringStandardDeviationAllTimeCalculator.getScoringStandardDeviation(league)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(6, len(response.keys()))
+        self.assertEqual(Deci("0.5"), response[owners[0].id])
+        self.assertTrue(math.isclose(Deci("1"), response[owners[1].id]))
+        self.assertEqual(Deci("0.08164965809277260327324280249"), response[owners[2].id])
+        self.assertEqual(Deci("0.08164965809277260327324280249"), response[owners[3].id])
+        self.assertEqual(Deci("0.08164965809277260327324280249"), response[owners[4].id])
+        self.assertEqual(Deci("0.08164965809277260327324280249"), response[owners[5].id])
+
     def test_getScoringStandardDeviation_noneIfNoGamesPlayed(self):
         owners, teamsA = getNDefaultOwnersAndTeams(3)
 
